@@ -1,5 +1,6 @@
 use UI::KeyboardLayout;
 use strict;
+use utf8;
 my $home = $ENV{HOME} || '';
 $home = "$ENV{HOMEDRIVE}$ENV{HOMEPATH}" if $ENV{HOMEDRIVE} and $ENV{HOMEPATH};
 UI::KeyboardLayout::->set_NamesList(qq($home/Downloads/NamesList.txt),
@@ -25,13 +26,31 @@ die "Usage: $0 KBDD_FILE\n" unless @ARGV == 1;
 my $l = UI::KeyboardLayout::->new_from_configfile(shift);
 
 my $skip_dummy = -e 'dummy';
-for my $kbd ([qw(ooo-us Latin)], [qw(ooo-ru CyrillicPhonetic)], [qw(ooo-gr GreekPoly)], [qw(ooo-hb Hebrew)]) {
+my($O, @add) = ('', <<'EOT', <<'EOT', <<'EOT', <<'EOT');
+############# Latin Personality: Per key list (in UTF-8; double-prefix-key columns are in the table for Cyrillic personality):
+	AltGr-'	AltGr-`	AltGr-^	AltGr-~	AltGr-.	AltGr-,	AltGr-6	AltGr--	AltGr-/	AltGr-"	AltGr-;	AltGr-$	2Shf-SPC Shf-SPC AltGr-SPC 2xAGr-SP 3xAGr-SP
+EOT
+############# Cyrillic Personality: Per key list: (with µ meaning AltGr-SPACE)
+	AltGr-'	AltGr-^	AltGr-$	2Sft-SPC Sft-SPC AGr-SPC 2AGr-SPC  µ \	 µ [	 µ ]	 µ `
+EOT
+############# Greek Personality: Per key list:
+	\	[	]	`	AltGr-$	Sft-SPC AGr-SPC 2AGr-SPC
+EOT
+############# Hebrew Personality: Per key list:
+	AltGr-$	Sft-SPC AGr-SPC 2AGr-SPC
+EOT
+
+my @kbd = ([qw(ooo-us Latin)], [qw(ooo-ru CyrillicPhonetic)], [qw(ooo-gr GreekPoly)], [qw(ooo-hb Hebrew)]);
+for my $kbd (map [@{$kbd[$_]}, $add[$_]], 0..$#kbd) {
   open my $kbdd, '>', $kbd->[0] or die;
   select $kbdd;
   print $l->fill_win_template(1, ['faces', $kbd->[1]]);
-  $l->print_coverage($kbd->[1]);
+  my $o = $l->print_coverage($kbd->[1]);
   # print "### RX_comb: <<<", $l->rxCombining, ">>>\n";
   close $kbdd or die;
+  
+  $O .= "\n" if length $O;
+  $O .= $kbd->[2] . $o;
 
   next if $skip_dummy;
   mkdir $_ for 'dummy', 'dummy2';
@@ -47,35 +66,34 @@ for my $kbd ([qw(ooo-us Latin)], [qw(ooo-ru CyrillicPhonetic)], [qw(ooo-gr Greek
   }
 }
 
-select STDOUT;
-open STDOUT, q(>), q(coverage-1prefix-Latin.html); 
-$l->print_table_coverage(q(Latin),		'html');
-open STDOUT, q(>), q(coverage-1prefix-Cyrillic.html);
-$l->print_table_coverage(q(CyrillicPhonetic),	'html');
-open STDOUT, q(>), q(coverage-1prefix-Greek.html); 
-$l->print_table_coverage(q(GreekPoly),		'html');
-open STDOUT, q(>), q(coverage-1prefix-Hebrew.html); 
-$l->print_table_coverage(q(Hebrew),		'html');
+$O =~ s/(?<=\S{7})\t(?![шщэ])/ /gi;	# All entries before шщэ are fixed by the following rule!
+$O =~ s/\t(?=\S{8})/ /g;
+$O =~ s/\t(?=⸣〃⸥⎖)/ /g;			# Last obstinate entry!
+open F, '>', 'text-tables' or die;
+print F $O;
+close F or die;
 
-unless (-e 'izKeys-visual-maps-base.html') {
-  require File::Copy;
-  File::Copy::copy('UI-KeyboardLayout/examples/izkeys-visual-maps-base.html', 'izKeys-visual-maps-base.html');
+select STDOUT;
+for my $kbd (@kbd) {
+  (my $o = $kbd->[1]) =~ s/(Poly|Phonetic)$//;
+  open STDOUT, q(>), qq(coverage-1prefix-$o.html); 
+  $l->print_table_coverage($kbd->[1], 'html', <<EOH);
+<link rel="shortcut icon" href="/~ilya/.images/favicon.ico">
+EOH
 }
 
-open F, '<', 'izKeys-visual-maps-base.html' or die "Can't open izKeys-visual-maps-base.html for read";
-my $html = do {local $/; <F>};
-close F or die "Can't close izKeys-visual-maps-base.html for read";
+for my $F ( qw{ izKeys-visual-maps logo izKeys-front } ) {
+  unless (-e "$F-base.html") {
+    require File::Copy;
+    File::Copy::copy("UI-KeyboardLayout/examples/$F-base.html", "$F-base.html");
+  }
 
-open STDOUT, q(>), q(izKeys-visual-maps-out.html); 
-print $l->apply_filter_div($l->apply_filter_style($html));
-open STDOUT, q(>), q(izKeys-visual-maps-fake.html); 
-print $l->apply_filter_div($l->apply_filter_style($html, {fake => 1}), {fake => 1});
+  open F, '<', "$F-base.html" or die "Can't open $F-base.html for read";
+  my $html = do {local $/; <F>};
+  close F or die "Can't close $F-base.html for read";
 
-open F, '<', 'logo-base.html' or die "Can't open logo-base.html for read";
-$html = do {local $/; <F>};
-close F or die "Can't close logo-base.html for read";
-
-open STDOUT, q(>), q(logo-out.html); 
-print $l->apply_filter_div($l->apply_filter_style($html));
-open STDOUT, q(>), q(logo-fake.html); 
-print $l->apply_filter_div($l->apply_filter_style($html, {fake => 1}), {fake => 1});
+  open STDOUT, q(>), qq($F-out.html); 
+  print $l->apply_filter_div($l->apply_filter_style($html));
+  open STDOUT, q(>), qq($F-fake.html); 
+  print $l->apply_filter_div($l->apply_filter_style($html, {fake => 1}), {fake => 1});
+}
